@@ -11,7 +11,7 @@ use Env qw( @PKG_CONFIG_PATH );
 use Config ();
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '1.65'; # VERSION
+our $VERSION = '1.74'; # VERSION
 
 
 sub _path { goto \&Path::Tiny::path }
@@ -96,7 +96,7 @@ sub load
     $class->meta;
   }};
 
-  my @preload = qw( Core::Setup Core::Download Core::FFI Core::Override );
+  my @preload = qw( Core::Setup Core::Download Core::FFI Core::Override Core::CleanInstall );
   push @preload, @Alien::Build::rc::PRELOAD;
   push @preload, split ';', $ENV{ALIEN_BUILD_PRELOAD}
     if defined $ENV{ALIEN_BUILD_PRELOAD};
@@ -525,7 +525,7 @@ sub download
           }
           else
           {
-            $self->log("multiple files, assuming directoryn");
+            $self->log("multiple files, assuming directory");
             $self->install_prop->{complete}->{download} = 1;
             $self->install_prop->{download} = _path('.')->absolute->stringify;
             $valid = 1;
@@ -765,6 +765,16 @@ sub test
 }
 
 
+sub clean_install
+{
+  my($self) = @_;
+  if($self->install_type eq 'share')
+  {
+    $self->_call_hook("clean_install");
+  }
+}
+
+
 sub system
 {
   my($self, $command, @args) = @_;
@@ -1151,7 +1161,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 1.65
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -1537,6 +1547,31 @@ your library is something like C<libarchive.so> or C<archive.dll> you
 would set this to C<archive>.  This may be a string or an array of
 strings.
 
+=item ffi_checklib
+
+This property contains two sub properties:
+
+=over 4
+
+=item share
+
+ $build->runtime_prop->{ffi_checklib}->{share} = [ ... ];
+
+Array of additional L<FFI::CheckLib> flags to pass in to C<find_lib>
+for a C<share> install.
+
+=item system
+
+Array of additional L<FFI::CheckLib> flags to pass in to C<find_lib>
+for a C<system> install.
+
+Among other things, useful for specifying the C<try_linker_script>
+flag:
+
+ $build->runtime_prop->{ffi_checklib}->{system} = [ try_linker_script => 1 ];
+
+=back
+
 =item install_type
 
 The install type.  Is one of:
@@ -1763,6 +1798,16 @@ The C<gather_system> hook will be executed.
 
 Run the test phase
 
+=head2 clean_install
+
+ $build->clean_install
+
+Clean files from the final install location.  The default implementation removes all
+files recursively except for the C<_alien> directory.  This is helpful when you have
+an old install with files that may break the new build.
+
+For a non-share install this doesn't do anything.
+
 =head2 system
 
  $build->system($command);
@@ -2021,7 +2066,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey
+Roy Storey (KIWIROY)
 
 Ilya Pavlov
 
